Learn R Programming

AsthmaNHANES (version 1.1.0)

metal: metal

Description

The metal data frame has 30,442 rows and 27 columns.

Usage

data(metal)

Arguments

Format

This data frame contains the following columns:

RIAGENDR

Gender of the sample person

RIDAGEYR

Best age in years of the sample person at time of screening

RIDRETH1

Recode of reported race and ethnicity information

WTMEC5YR

Both interviewed and MEC examined sample persons

SDMVPSU

Masked Variance Unit Pseudo-PSU variable for variance estimation

SDMVSTRA

Masked variance unit pseudo-stratum variable for variance estimation

BMXBMI

Body mass index (kg/m^2)

LBXBPB

Lead (ug/dL)

LBXBCD

Cadmium (ug/L)

LBXCOT

Cotinine (ng/mL)

MCQ010

Ever been told you have asthma

RDQ070

Wheezing or whistling in chest - past year

SMQ040

Do you now smoke cigarettes?

SMQ020

Smoked at least 100 cigarettes in life

MCQ035

Still have asthma?

OCD390G

Kind of work you have done the longest

HIQ011

Covered by health insurance

MCQ300B

Close relative had asthma?

INDHHIN2

Annual household income

ENQ090

Close relative had asthma?

ENXTR1Q

Trial 1 FENO measurement (ppb)

SPXNFVC

Baseline 1st test spirometry, forced vital capacity

SPXNFEV1

Baseline 1st test spirometry, forced expiratory volume in the first 1 second

SPDBRONC

Best test FEV1/FVC ratio below Lower Limit of Normal and/or less than 0.7

SPXBFVC

Bronchodilator 2nd test spirometry, forced vital capacity

SPXBFEV1

Bronchodilator 2nd test spirometry, forced expiratory volume in the first 1 second

LBXVIDMS

25-hydroxyvitamin D2 and D3

Examples

Run this code
# NOT RUN {
# Load data
data(metal)
# View data
summary(metal)
# }

Run the code above in your browser using DataLab