The metal data frame has 30,442 rows and 27 columns.
data(metal)This data frame contains the following columns:
Gender of the sample person
Best age in years of the sample person at time of screening
Recode of reported race and ethnicity information
Both interviewed and MEC examined sample persons
Masked Variance Unit Pseudo-PSU variable for variance estimation
Masked variance unit pseudo-stratum variable for variance estimation
Body mass index (kg/m^2)
Lead (ug/dL)
Cadmium (ug/L)
Cotinine (ng/mL)
Ever been told you have asthma
Wheezing or whistling in chest - past year
Do you now smoke cigarettes?
Smoked at least 100 cigarettes in life
Still have asthma?
Kind of work you have done the longest
Covered by health insurance
Close relative had asthma?
Annual household income
Close relative had asthma?
Trial 1 FENO measurement (ppb)
Baseline 1st test spirometry, forced vital capacity
Baseline 1st test spirometry, forced expiratory volume in the first 1 second
Best test FEV1/FVC ratio below Lower Limit of Normal and/or less than 0.7
Bronchodilator 2nd test spirometry, forced vital capacity
Bronchodilator 2nd test spirometry, forced expiratory volume in the first 1 second
25-hydroxyvitamin D2 and D3
# NOT RUN {
# Load data
data(metal)
# View data
summary(metal)
# }
Run the code above in your browser using DataLab